import _pulsar
from . import Record as Record
from .schema import Schema as Schema
from _typeshed import Incomplete

HAS_AVRO: bool

class AvroSchema(Schema):
    def __init__(self, record_cls, schema_definition: Incomplete | None = None) -> None: ...
    def encode(self, obj): ...
    def encode_dict(self, d): ...
    def decode(self, data): ...
    def decode_message(self, msg: _pulsar.Message): ...

class AvroSchema(Schema):
    def __init__(self, _record_cls, _schema_definition: Incomplete | None = None) -> None: ...
    def encode(self, obj) -> None: ...
    def decode(self, data) -> None: ...
