import abc
from abc import abstractmethod

class SerDe(metaclass=abc.ABCMeta):
    @abstractmethod
    def serialize(self, input): ...
    @abstractmethod
    def deserialize(self, input_bytes): ...

class PickleSerDe(SerDe):
    def serialize(self, input): ...
    def deserialize(self, input_bytes): ...

class IdentitySerDe(SerDe):
    def __init__(self) -> None: ...
    def serialize(self, input): ...
    def deserialize(self, input_bytes): ...
